# Startup script for Automic ONE Automation Java User Interface (UC4 GUI)
# (c) 2016 Michael A. Lowry <michael.lowry@gmail.com> <michael_lowry@swissre.com>
# Swiss Re
#
# Version    Date          Description
# 2          2016.10.26    Write all output, including UCDJ stdout & stderr, to log file.
# 1          2016.08.09    Initial port of BAT script to PowerShell

param (
    [Parameter(Mandatory=$true)][string]$uc4env,
    [Parameter(Mandatory=$true)][string]$uc4ver,
    # Default JRE, if not specified:
    [string]$jrever="jre1.8.0_66"
)

$host.UI.RawUI.BufferSize = new-object System.Management.Automation.Host.Size(512,50)
$myDocuments = [Environment]::GetFolderPath("MyDocuments")
$datetime = Get-Date -format yyyy.MM.dd_HH.mm.ss
$cwdlong = Get-Location
$fso = New-Object -ComObject Scripting.FileSystemObject
$cwd = $fso.GetFolder($cwdlong)
$scriptdir = $cwd.ShortPath
$userprofile = $env:userprofile
$ucdjdir = "$ScriptDir\UCDJ\v$uc4ver\bin"
$jredir = "$ScriptDir\Java\$jrever"
$configdir = "$myDocuments\UC4\UCDJ\$uc4env\v$uc4ver"
$uc4config = "$configdir\uc4config-$uc4env.xml"
$logindat  = "$configdir\login_dat-$uc4env.xml"
$username = $env:username
$logdir    = "$configdir\logs"
$logfile   = "$logdir\UCDJ_${uc4env}_log_$datetime.txt"

# Start writing to log
$ErrorActionPreference="SilentlyContinue"
Stop-Transcript | out-null
$ErrorActionPreference = "Continue"
Start-Transcript -path $logfile -append

Switch ($uc4env)
	{
	"EXP"  { $uc4env_desc = "Experimental"}
	"EXP2" { $uc4env_desc = "Experimental 2"}
	"DEV"  { $uc4env_desc = "Development"}
	"ITE"  { $uc4env_desc = "Integrated Test Env."}
	"PROD" { $uc4env_desc = "Production"}
	default {
        Write-Host "ERROR: Unknown UC4 environment: $uc4env"
        Exit 1}
}
Switch ($uc4ver)
	{
	"9"         {}
	"11.2.1"    {}
	"11.2.2"    {}
	"12"        {}
	default {
        Write-Host "ERROR: Unsupported UC4 version: $uc4ver"
        Exit 1}
}
Write-Host "UC4 Environment      : $uc4env ($uc4env_desc)"
Write-Host "UC4 Version          : $uc4ver"
Write-Host "JRE Version          : $jrever"
Write-Host "Working dir. (long)  : $cwdlong"
Write-Host "Working dir. (short) : $scriptdir"
Write-Host "User home (long)     : $userprofile"
Write-Host "UCDJ directory       : $ucdjdir"
Write-Host "JRE directory        : $jredir"
Write-Host "Config. directory    : $configdir"
Write-Host "UI config. XML file  : $uc4config"
Write-Host "UI login data file   : $logindat"
Write-Host "Log directory        : $logdir"
Write-Host "Log file             : $logfile"
Write-Host "User name            : $username"

if((Test-Path "$configdir") -eq 0) {
    Write-Host "Directory $configdir does not exist. Creating it."
    New-Item -ItemType Directory -Force -Path $configdir
}
if((Test-Path "$logdir") -eq 0) {
    Write-Host "Directory $logdir does not exist. Creating it."
    New-Item -ItemType Directory -Force -Path $logdir
}
if((Test-Path "$uc4config") -eq 0) {
    Write-Host "Copying default UC4 UI config file for $uc4env (uc4config-$uc4env.xml) to $configdir."
    Copy-Item "$cwdlong\config\uc4config-$uc4env.xml" -Destination "$configdir"
}
if((Test-Path "$logindat") -eq 0) {
    Write-Host "Copying default UC4 UI login data file for $uc4env (login_dat-$uc4env.xml) to $configdir."
    Copy-Item "$cwdlong\config\login_dat-$uc4env.xml" -Destination "$configdir"
}
if((Test-Path "$configdir\docu") -eq 0) {
    Write-Host "Copying default UC4 documentation stub html file for $uc4env to $configdir."
    Copy-Item "$cwdlong\UCDJ\v$uc4ver\docu" -Destination "$configdir" -Recurse
}

cd $configdir
$userdir  = $configdir

$ucdjjar   = "$ucdjdir\ucdj-$uc4env.jar"
if((Test-Path "$ucdjjar") -eq 0) {
    Write-Host ""
    Write-Host "****************************************"
    Write-Host "ERROR: UCDJ JAR file $ucdjjar not found!"
    Write-Host "****************************************"
    cd $cwdlong
    Exit 1
}

$classpath = "$ucdjdir;$ucdjjar"
$krb5debug = "`"-Dsun.security.krb5.debug=true`""
#$javatmpdir = "`"-Djava.io.tmpdir=$configdir`""
$javaopts  = "`"-Xmx1024m`" `"-XX:+UseG1GC`" `"-XX:MinHeapFreeRatio=40`" `"-XX:MaxHeapFreeRatio=70`" `"-XX:+HeapDumpOnOutOfMemoryError`" `"-XX:HeapDumpPath=$logdir`" `"-Dsun.locale.formatasdefault=true`" `"$krb5debug`" `"-Duser.dir=$userdir`""
$mainclass = "com/uc4/ucdf/UCDialogFactory"
$ucdjopts  = "`"-U$username`" `"-I$uc4config`" `"-O$logindat`""

Write-Host "Java class path      : $classpath"
Write-Host "Java options         : $javaopts"
Write-Host "Java main class      : $mainclass"
Write-Host "UCDJ options         : $ucdjopts"

# Echo to the log the UCDJ command that will be run
Write-Host "Running command: $jredir\bin\java.exe $javaopts -cp $classpath $mainclass $ucdjopts >>$logfile 2>&1"

# Stop writing to log
Stop-Transcript

# Run the UI in the selected JRE and append stdout & stderr to log
. $jredir\bin\java.exe $javaopts -cp $classpath $mainclass $ucdjopts >>$logfile 2>&1
cd $cwdlong